# Cythonization Report

This report summarizes the Cythonization percentage for various source files, indicating the level of Python interaction within the compiled code.

---
## Overall Summary

| Metric                                 | Value       |
| :------------------------------------- | :---------- |
| Total Score Sum                        | 6486.0      |
| Possible Score                         | 105200.0      |
| Total Non-Empty Lines                  | 1052.0      |
| Python Overhead Lines                  | 403.0      |
| **Overall Cythonization Percentage** | **93.83%** |
| **Overall Python Overhead Lines Percentage** | **38.31%** |

---
## File: _test_helpers.html

| Metric                         | Value       |
| :----------------------------- | :---------- |
| Total Score Sum                | 1412      |
| Possible Score                 | 11300      |
| Total Non-Empty Lines          | 113      |
| Python Overhead Lines          | 43      |
| **Cythonization Percentage** | **87.5%** |
| **Python Overhead Lines Percentage** | **38.05%** |

---
## File: rk4_engine.html

| Metric                         | Value       |
| :----------------------------- | :---------- |
| Total Score Sum                | 94      |
| Possible Score                 | 1900      |
| Total Non-Empty Lines          | 19      |
| Python Overhead Lines          | 8      |
| **Cythonization Percentage** | **95.05%** |
| **Python Overhead Lines Percentage** | **42.11%** |

---
## File: base_engine.html

| Metric                         | Value       |
| :----------------------------- | :---------- |
| Total Score Sum                | 2247      |
| Possible Score                 | 47000      |
| Total Non-Empty Lines          | 470      |
| Python Overhead Lines          | 161      |
| **Cythonization Percentage** | **95.22%** |
| **Python Overhead Lines Percentage** | **34.26%** |

---
## File: euler_engine.html

| Metric                         | Value       |
| :----------------------------- | :---------- |
| Total Score Sum                | 94      |
| Possible Score                 | 1900      |
| Total Non-Empty Lines          | 19      |
| Python Overhead Lines          | 8      |
| **Cythonization Percentage** | **95.05%** |
| **Python Overhead Lines Percentage** | **42.11%** |

---
## File: traj_data.html

| Metric                         | Value       |
| :----------------------------- | :---------- |
| Total Score Sum                | 1006      |
| Possible Score                 | 12500      |
| Total Non-Empty Lines          | 125      |
| Python Overhead Lines          | 56      |
| **Cythonization Percentage** | **91.95%** |
| **Python Overhead Lines Percentage** | **44.8%** |

---
## File: _test_engine.html

| Metric                         | Value       |
| :----------------------------- | :---------- |
| Total Score Sum                | 850      |
| Possible Score                 | 10700      |
| Total Non-Empty Lines          | 107      |
| Python Overhead Lines          | 35      |
| **Cythonization Percentage** | **92.06%** |
| **Python Overhead Lines Percentage** | **32.71%** |

---
## File: bind.html

| Metric                         | Value       |
| :----------------------------- | :---------- |
| Total Score Sum                | 783      |
| Possible Score                 | 19900      |
| Total Non-Empty Lines          | 199      |
| Python Overhead Lines          | 92      |
| **Cythonization Percentage** | **96.07%** |
| **Python Overhead Lines Percentage** | **46.23%** |

---
Generated on 2025-11-28 14:14:08.
